@@ -7,12 +7,12 @@
 
     pn.extension()
 
-    modal = Modal(object=pn.panel("Hi. I am the Panel Modal!", width=200))
+    modal = Modal(pn.panel("Hi. I am the Panel Modal!", width=200))
 
     pn.Column(modal.param.open, modal).servable()
 """
 from .modal import Modal
 
-VERSION = "0.1.0"
+VERSION = "0.2.0"
 
 __all__ = ["Modal", "VERSION"]
